==> jc-1.4.0.tar.gz: javax/print/DocFlavor__24SERVICE__5fFORMATTED.h <==
// public class javax.print.DocFlavor$SERVICE_FORMATTED

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a95dbf9c9d048d51 javax_print_DocFlavor
// @dep_class ce1cfe7486132d15 javax_print_DocFlavor__24SERVICE__5fFORMATTED

// header file dependencies
// @dep_header javax_print_DocFlavor

#include "javax/print/DocFlavor.h"

#ifndef _JC_javax_print_DocFlavor__24SERVICE__5fFORMATTED_H_
#define _JC_javax_print_DocFlavor__24SERVICE__5fFORMATTED_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object;

// Typedefs
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_refs	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_refs;
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_nonrefs	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_nonrefs;
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$refs	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$refs;
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$nonrefs	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$nonrefs;
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object;

typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$fields_struct	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$fields_struct;
typedef const struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vmethods	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vmethods;
typedef const struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtable	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtable;
typedef const struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype;

// Class fields structure
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$fields_struct {
	struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object	*PAGEABLE;
	struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object	*PRINTABLE;
	struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object	*RENDERABLE__5fIMAGE;
	jlong	serialVersionUID;
};
extern _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$fields_struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$class_fields;

// Constructors
extern void _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vmethods {
};

// Vtable
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_DocFlavor$vmethods	javax_print_DocFlavor;
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vmethods	javax_print_DocFlavor__24SERVICE__5fFORMATTED;
};

// Vtype
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype {
	_jc_type			type;
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$refs {
    _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_refs	javax_print_DocFlavor__24SERVICE__5fFORMATTED;
    _jc_javax_print_DocFlavor$sub_refs	javax_print_DocFlavor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_DocFlavor$sub_nonrefs	javax_print_DocFlavor;
    _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_nonrefs	javax_print_DocFlavor__24SERVICE__5fFORMATTED;
};

// Object instance structure
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object {
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype	*vtype;
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_DocFlavor__24SERVICE__5fFORMATTED, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$class_object;

#endif	/* _JC_javax_print_DocFlavor__24SERVICE__5fFORMATTED_H_ */

==> jc-1.4.6.tar.gz: javax/print/DocFlavor__24SERVICE__5fFORMATTED.h <==
// public class javax.print.DocFlavor$SERVICE_FORMATTED

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a95dbf9c9d048d51 javax_print_DocFlavor
// @dep_class ce1cfe7486132d15 javax_print_DocFlavor__24SERVICE__5fFORMATTED

// header file dependencies
// @dep_header javax_print_DocFlavor

#include "javax/print/DocFlavor.h"

#ifndef _JC_javax_print_DocFlavor__24SERVICE__5fFORMATTED_H_
#define _JC_javax_print_DocFlavor__24SERVICE__5fFORMATTED_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object;

// Typedefs
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_refs	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_refs;
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_nonrefs	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_nonrefs;
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$refs	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$refs;
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$nonrefs	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$nonrefs;
typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object;

typedef struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$fields_struct	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$fields_struct;
typedef const struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vmethods	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vmethods;
typedef const struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtable	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtable;
typedef const struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype;

// Class fields structure
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$fields_struct {
	struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object	*PAGEABLE;
	struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object	*PRINTABLE;
	struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object	*RENDERABLE__5fIMAGE;
	jlong	serialVersionUID;
};
extern _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$fields_struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$class_fields;

// Constructors
extern void _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vmethods {
};

// Vtable
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_DocFlavor$vmethods	javax_print_DocFlavor;
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vmethods	javax_print_DocFlavor__24SERVICE__5fFORMATTED;
};

// Vtype
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype {
	_jc_type			type;
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$refs {
    _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_refs	javax_print_DocFlavor__24SERVICE__5fFORMATTED;
    _jc_javax_print_DocFlavor$sub_refs	javax_print_DocFlavor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_DocFlavor$sub_nonrefs	javax_print_DocFlavor;
    _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$sub_nonrefs	javax_print_DocFlavor__24SERVICE__5fFORMATTED;
};

// Object instance structure
struct _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$object {
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype	*vtype;
	_jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$vtype _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_DocFlavor__24SERVICE__5fFORMATTED, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_DocFlavor__24SERVICE__5fFORMATTED$class_object;

#endif	/* _JC_javax_print_DocFlavor__24SERVICE__5fFORMATTED_H_ */
